## dbt-adapters 1.19.0 - November 07, 2025

### Features

- Add utilities to support adapter implementations to support python UDFs ([#1410](https://github.com/dbt-labs/dbt-adapters/issues/1410))
- Begin looking up function macro by function type and language ([#1409](https://github.com/dbt-labs/dbt-adapters/issues/1409))

### Under the Hood

- Use Recorder.record_row_limit if available when serializing agate.Table in record-mode ([#1424](https://github.com/dbt-labs/dbt-adapters/issues/1424))

### Dependencies

- Bump minimum dbt-common to 1.36.0 ([#1424](https://github.com/dbt-labs/dbt-adapters/pull/1424))
